@@ -73,7 +73,9 @@ test_that("Check RAthena s3 dplyr sql_translate_env method",{
   t27 <- translate_sql(iris[[1]], con = con)
   t28 <- grepl("^Athena.*\\[.*/.*\\]", dplyr::db_desc(con))
   t29 <- dbDataType(con, dt)
+  noctua_options()
   t30 <- noctua:::AthenaToRDataType.athena_data.table(method, data_types)
+  noctua_options("vroom")
   t31 <- noctua:::AthenaToRDataType.athena_vroom(method, data_types)
   t32 <- noctua:::sql_escape_date.AthenaConnection(con, "2020-01-01")
   t33 <- noctua:::sql_escape_datetime.AthenaConnection(con, "2020-01-01")
